haven labels to dic files
haven_dic.RdConvert haven labelled data frames to dic files
Details
This function converts a data frame with haven labels into a data frame containing dic information. Item labels and value labels are extracted from the haven attributes and stored in dic attributes.
Examples
ex_itrf_dic <- haven_dic(ex_itrf, remove_haven_class = TRUE)
ex_itrf_copy <- dic_haven(ex_itrf_dic)