Skip to contents

Prints dic infos of a variable with dic infos.

Usage

print_dic(x, length = 100, ...)

Arguments

x

A variable with dic infos.

length

Number of entries to be printed.

...

Unused future parameters.

Value

Dic infos of x and the first length entries of x.