Build a dictionary file template for scale definition
build_scaledic_skeleton.RdThis function builds an empty skeleton of a dictionary file for scale definition. It can either write an Excel file or return a data frame.
Value
When 'filename' is not empty, it writes an Excel file with an empty template of a dic file. When 'filename' is NA, returns a data frame.
Details
The skeleton contains all necessary variable names for a dic file. The user can specify the number of empty rows to be added to the data frame. This is useful when creating a dic file for a data frame with many variables. The function uses the variable names defined in the option 'dic_file_vars'. These can be modified by the user if needed. The function uses the 'openxlsx' package to write the Excel file. Make sure to have it installed.