Concatenate dic vectors while keeping dic metadata from the first argument
c.dic.RdKeeps dic attributes from the first dic argument and restores them after concatenation.
Usage
# S3 method for class 'dic'
c(..., recursive = FALSE)
c.dic.RdKeeps dic attributes from the first dic argument and restores them after concatenation.
# S3 method for class 'dic'
c(..., recursive = FALSE)