replace_missing.Rd
This function replaces missing values in a data frame based on the missing value definitions provided in the dic attributes of the variables. Variables without dic attributes are ignored.
replace_missing(data, replace = NA, report = TRUE)
A data frame
Replace value for missing values (default is NA).
If TRUE, proportion of missing values is printed.
A data frame with replaced missing values.